#thumbnail-view .folder-item,
#thumbnail-view .more-item {
    /*float: left;
    margin: 4px 8px 4px 0;
    padding: 6px;
    height: 250px;
	width:128px;
    border: 1px solid #ccc;
    border-radius: 4px;
    text-align: center;
    
    position: relative;*/
}

#thumbnail-view .folder-item div.thumbnail, #thumbnail-view .more-item div.thumbnail {
    /*height: 300px;*/
    position: relative;
}

#thumbnail-view .folder-item {
    display: none;
    overflow: hidden;
}

#thumbnail-view .folder-item .thumbnail,
#thumbnail-view .more-item .thumbnail {
    /*display: block;
    margin:10px auto;
    z-index: 9999;*/
    overflow: hidden;
}


#thumbnail-view .folder-item .thumbnail-wrapper,
#thumbnail-view .more-item .thumbnail-wrapper {
    /*height: 170px;*/
}

#thumbnail-view .folder-item .thumbnail-wrapper img,
#thumbnail-view .more-item .thumbnail-wrapper img {
    /*max-height: 170px;*/
}

#thumbnail-view .buttons {
    display: block;
    clear: both;
    text-align: center;
    padding: 1em;
}

#thumbnail-view .button {
    display: inline;
}

#thumbnail-view .folder-item:hover div.thumbnail, #thumbnail-view .more-item:hover div.thumbnail,
#thumbnail-view .folder-item[class*="copy"][class*="_of_"]:hover .thumbnail {
    /*background-color: #EEEEEE;*/
    border-color: #428bca;
}

#thumbnail-view .img-responsive {
    margin: 0 auto;
}

#thumbnail-view .item-title {
    overflow:hidden;
    white-space: nowrap;
    text-overflow: ellipsis;
    max-width: 100%;
    /*height:4.5em;*/
    font-size: 90%;
    /*word-wrap: break-word;
    word-break: break-all;*/
    margin-top: 10px
}

#thumbnail-view .item-title span {
    padding-left: 5px;
}

#thumbnail-view .folder-item.Folder div.thumbnail {
    background:#EAEAEA;
}

.link-view {
    float: left;
    padding: 10px;
}

.link-edit {
    float: right;
    padding: 10px;
}

.preview-image {
    display: block;
    margin: 0 auto;
}

#folder_name{
    text-align: center;
}

.more-item {
    cursor: pointer;
}



#thumbnail-viewlet {
    display: none;
}

#thumbnail-viewlet.File,
#thumbnail-viewlet.Link{
    display: block;
}

#thumbnail-view .folder-item .toolbar, .folder-item.ui-sortable-helper .toolbar {
    position: absolute;
    top: 0;
    left: 0;
    right: 0;
}

#thumbnail-view .folder-item .toolbar .holder {
    /*background-color: #000;
    background-color: rgba(0,0,0,0.7);*/
    background-color: #e6e6e6;
    border-bottom: 1px solid #ddd;
    color: #222;
    display: none;
    margin: 0;
    padding: 2px 5px;
    height: auto;
}

.folder-item.ui-sortable-helper .toolbar {
    background: none;
    display: none !important;
}

#thumbnail-view .folder-item.state-checked div.thumbnail {
    border-color: #f0ad4e !important;
}

#thumbnail-view .folder-item .toolbar input, .folder-item.ui-sortable-helper .toolbar input {
    margin-top: 3px;
}

#thumbnail-view .folder-item .toolbar .delete, .folder-item.ui-sortable-helper .toolbar .delete {
    float: right;
    font-size: 1.2em;
    cursor: pointer;
    color: #222;
    /*color: rgba(255, 255, 255, .9);*/
}


#thumbnail-view .folder-item .thumbnail a.thumbnail-holder {
    height: 100%;
}

#thumbnail-view .folder-item .additional-information {
    position: absolute;
    bottom: 0;
    left: 0;
    right: 0;
}

#thumbnail-view .folder-item .additional-information .holder {
    /*background-color: #000;
    background-color: rgba(0,0,0,0.7);*/
    background-color: #e6e6e6;
    border-top: 1px solid #ddd;
    color: #222;
    display: none;
    margin: 0;
    padding: 5px 5px 0;
    height: auto;
}


#thumbnail-view .folder-item.list-group .additional-information {
    position: initial;
    padding-left: 0;
    padding-right: 0;
}

#thumbnail-view .folder-item.list-group .additional-information .holder {
    display: block !important;
    background: none;
    color: #333;
}


#thumbnail-view .folder-item.list-group .additional-information-trigger {
    display: none;
}


#thumbnail-view .folder-item .additional-information-trigger {
    position: absolute;
    bottom: 0;
    right: 0;
    z-index: 1;
}

#thumbnail-view .folder-item .additional-information-trigger .inner {
    /*background-color: #999;*/
    padding: 5px;
    /*-webkit-border-top-left-radius: 1000px;
        -moz-border-radius-topleft: 1000px;
            border-top-left-radius: 1000px;*/
    text-align: right;
    font-size: 20px;
    font-weight: bold;
    line-height: 0;
    cursor: pointer;
}

#thumbnail-view .folder-item .additional-information-trigger .inner i.fa {
    margin-top: 5px;
    margin-left: 5px;
}


#thumbnail-view .folder-item .additional-information .item-title {
    font-size: 12px!important;
}

#thumbnail-view .folder-item .additional-information i {
    padding-top: 3px;
}

#thumbnail-view .folder-item .additional-information i.icon-file-text-alt {
    padding-top: 10px;
}

#thumbnail-view .folder-item .additional-information i.fa-edit {
    padding-bottom: 10px;
}

#thumbnail-viewlet .thumbnail {
    padding:0;
    margin:0;
    
}

#thumbnail-view .folder-item .additional-information i {
    width: 20px;
    text-align: center;
}




#thumbnail-view a.link-overlay {
	border-bottom: none !important;
}

#thumbnail-view .folder-item[class*="copy"][class*="_of_"] .thumbnail {
    border: 1px dashed #ccc;
}

.show-preview #edit-bar {
	display: block;
	/*padding: 1em;*/
	width: 100%;
        height:42px;
}

.show-preview #content-views {
	margin: 0 auto;
	height: 100%;
}

.show-preview #content-views li {
    float: left;
    margin-left: 10px;
    cursor: pointer;
}

.show-preview #content-views li i {
    height: 100%;
    padding: 10px;
}

.show-preview #content-views li:first-child {
    margin-left: 0;
}

.show-preview #content-views li.selected .content-view-box .text {
    font-weight: bold;
}

.show-preview #content-views li .content-view-box .text {
    display: none;
}

.show-preview #content-views a, .show-preview #content li.formTab a {
	display: none !important;
	background: none repeat scroll 0 0 rgba(250, 250, 250, 0.95);
    border: 1px solid #CCCCCC;
    border-radius: 4px 4px 4px 4px;
    box-shadow: 0 0 12px rgba(100, 100, 100, 0.6);
    font-size: 11px;
    min-width: 100px;
    opacity: 0.98;
    padding: 4px;
    position: absolute;
    text-align: center;
    margin-top: -22px;
    margin-left: -50px;
    z-index: 2;
}

.show-preview #content-views li:hover a, #content li.formTab:hover a {
	display: inline-block;
}


#thumbnail-view .thumbnail-listing-size {
    float: right;
/*    font-family: FontAwesome;
    font-weight: normal;
    font-style: normal;
    text-decoration: inherit;
    -webkit-font-smoothing: antialiased;
    *margin-right: .3em;
    font-size: 1.2em;
    cursor: pointer;*/
}
#thumbnail-view .thumbnail-listing-size a:hover {
    text-decoration: none;
    color: #000;
}

#thumbnail-view .thumbnail-listing-size a.state-active {
    color: #000;
}

#thumbnail-view .thumbnail-listing-size i.fa {
    /*font-size: 22px;*/
}

#thumbnail-view .thumbnail-listing-size .btn,
#thumbnail-view .thumbnail-listing-sort .btn {
	margin-right: 0;
}

#thumbnail-view .thumbnail-listing-sort ul {
	list-style: none;
	margin-left: 0;
}

#thumbnail-view .thumbnail-listing-size .btn.state-active[disabled] {
	color: #428bca;
	opacity: 1;
	filter: Alpha(opacity=100);
}

.tumbnail-controls + .container-off {
	margin-top: 25px;
}

/*
#thumbnail-view .thumbnail-listing-size:before {
    text-decoration: inherit;
    display: inline-block;
    speak: none;
}

#thumbnail-view .thumbnail-listing-size:before {
    content: '\f00a';
}

#thumbnail-view.small-view .thumbnail-listing-size:before {
    content: '\f009';
}

#thumbnail-view.list-view .thumbnail-listing-size:before {
    content: '\f039';
}
*/


#thumbnail-view.small-view .folder-item, #thumbnail-view.small-view .more-item {
    width: 65px;
    height: 110px;
}

#thumbnail-view.small-view .folder-item .thumbnail-wrapper {
    height: 60px;
}

#thumbnail-view.small-view .folder-item .thumbnail-wrapper img {
    max-width: 100%;
    max-height: 50px;
            box-sizing: border-box;
       -moz-box-sizing: border-box;
    -webkit-box-sizing: border-box;
}

#thumbnail-view.small-view .folder-item .additional-information {
    display: none;
}

#thumbnail-view.small-view .folder-item .item-title {
    line-height: 1em;
    height: 2em;
    overflow: hidden;
}

#thumbnail-view.small-view .folder-item .item-title img {
    display: none;
}

#thumbnail-view.small-view .folder-item .item-title[class*="contenttype-"] {
    background: none;
    padding-left: 0 !important;
}

#thumbnail-view.small-view .more-item img {
    max-width: 60px;
}








.folder-item.list-group, .more-item.list-group {
    padding-left: 15px;
}

#thumbnail-view .folder-item.list-group div.thumbnail, #thumbnail-view .more-item.list-group div.thumbnail {
    height: auto;
}

#thumbnail-view .more-item.list-group div.thumbnail {
    text-align: center;
}

#thumbnail-view .more-item.list-group div.thumbnail a {
    width: 100% !important;
}

#thumbnail-view .folder-item.list-group .item-title {
    overflow: initial;
    white-space: initial;
    text-overflow: initial;
}




.thumbnail-listing-sort #thumbnail-listing-sort-method:after {
    display: inline-block;
    font-family: FontAwesome;
    margin-left: 5px;
    font-size: 13px;
}

.thumbnail-listing-sort #thumbnail-listing-sort-method.sort-asc:after {
    content: '\f0d8';
}

.thumbnail-listing-sort #thumbnail-listing-sort-method.sort-desc:after {
    content: '\f0d7';
}
















